@@ -1,35 +1,38 @@
 # source: http://docs.gunicorn.org/en/stable/custom.html
-from __future__ import unicode_literals
-
 import multiprocessing
+from typing import Dict, Optional
 
 import gunicorn.app.base
-from gunicorn.six import iteritems
+from flask import Flask
 from twootfeed import create_app, param
 
 
 class StandaloneApplication(gunicorn.app.base.BaseApplication):
-
-    def __init__(self, app, options=None):
+    def __init__(
+        self, current_app: Flask, options: Optional[Dict] = None
+    ) -> None:
         self.options = options or {}
-        self.application = app
-        super(StandaloneApplication, self).__init__()
+        self.application = current_app
+        super().__init__()
 
-    def load_config(self):
-        config = dict([(key, value) for key, value in iteritems(self.options)
-                       if key in self.cfg.settings and value is not None])
-        for key, value in iteritems(config):
+    def load_config(self) -> None:
+        config = {
+            key: value
+            for key, value in self.options.items()
+            if key in self.cfg.settings and value is not None
+        }
+        for key, value in config.items():
             self.cfg.set(key.lower(), value)
 
-    def load(self):
+    def load(self) -> Flask:
         return self.application
 
 
-def number_of_workers():
+def number_of_workers() -> int:
     return (multiprocessing.cpu_count() * 2) + 1
 
 
-def main():
+def main() -> None:
     app = create_app()
     options = {
         'bind': f"{param['app']['host']}:{param['app']['port']}",
