@@ -1,7 +1,10 @@
+from logging import Logger
+from typing import Dict, Optional
+
 import tweepy
 
 
-def get_twitter_api(param, app_log):
+def get_twitter_api(param: Dict, app_log: Logger) -> Optional[tweepy.API]:
     twitter_api = None
 
     try:
@@ -13,8 +16,10 @@ def get_twitter_api(param, app_log):
             twitter_api = tweepy.API(auth, wait_on_rate_limit=True)
 
         else:
-            app_log.warning('Twitter API: no consumer key and or consumer '
-                            'secret in config file.')
+            app_log.warning(
+                'Twitter API: no consumer key and or consumer '
+                'secret in config file.'
+            )
     except Exception as e:
         app_log.error(f'Twitter API: invalid config file ({e})')
 
